summaryrefslogtreecommitdiff
path: root/sys/dev/dm/dm_target_snapshot.c
diff options
context:
space:
mode:
authortkusumi <tkusumi@NetBSD.org>2019-12-15 05:56:02 +0000
committertkusumi <tkusumi@NetBSD.org>2019-12-15 05:56:02 +0000
commit23ef6e5dd08de606f940a71b427520d20082fd32 (patch)
tree04510307f6d0dd42d4239532b4bae0a4f0d47507 /sys/dev/dm/dm_target_snapshot.c
parentee241c51f0f2fba701d900b361985399bda33631 (diff)
dm: Rename targets' ->status() to ->table() given ->info() exists
Since now that dm targets in NetBSD have ->info() for "status", ->status() should be renamed to ->table() for "table", given how dm target status was originally designed in Linux kernel. taken-from: DragonFlyBSD
Diffstat (limited to 'sys/dev/dm/dm_target_snapshot.c')
-rw-r--r--sys/dev/dm/dm_target_snapshot.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/sys/dev/dm/dm_target_snapshot.c b/sys/dev/dm/dm_target_snapshot.c
index ab9c8622c29..d96af2139b3 100644
--- a/sys/dev/dm/dm_target_snapshot.c
+++ b/sys/dev/dm/dm_target_snapshot.c
@@ -1,4 +1,4 @@
-/* $NetBSD: dm_target_snapshot.c,v 1.31 2019/12/14 10:02:35 tkusumi Exp $ */
+/* $NetBSD: dm_target_snapshot.c,v 1.32 2019/12/15 05:56:02 tkusumi Exp $ */
/*
* Copyright (c) 2008 The NetBSD Foundation, Inc.
@@ -29,7 +29,7 @@
* POSSIBILITY OF SUCH DAMAGE.
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: dm_target_snapshot.c,v 1.31 2019/12/14 10:02:35 tkusumi Exp $");
+__KERNEL_RCSID(0, "$NetBSD: dm_target_snapshot.c,v 1.32 2019/12/15 05:56:02 tkusumi Exp $");
/*
* 1. Suspend my_data to temporarily stop any I/O while the snapshot is being
@@ -88,7 +88,7 @@ __KERNEL_RCSID(0, "$NetBSD: dm_target_snapshot.c,v 1.31 2019/12/14 10:02:35 tkus
/* dm_target_snapshot.c */
int dm_target_snapshot_init(dm_table_entry_t *, int, char **);
-char *dm_target_snapshot_status(void *);
+char *dm_target_snapshot_table(void *);
int dm_target_snapshot_strategy(dm_table_entry_t *, struct buf *);
int dm_target_snapshot_sync(dm_table_entry_t *);
int dm_target_snapshot_deps(dm_table_entry_t *, prop_array_t);
@@ -97,7 +97,7 @@ int dm_target_snapshot_upcall(dm_table_entry_t *, struct buf *);
/* dm snapshot origin driver */
int dm_target_snapshot_orig_init(dm_table_entry_t *, int, char **);
-char *dm_target_snapshot_orig_status(void *);
+char *dm_target_snapshot_orig_table(void *);
int dm_target_snapshot_orig_strategy(dm_table_entry_t *, struct buf *);
int dm_target_snapshot_orig_sync(dm_table_entry_t *);
int dm_target_snapshot_orig_deps(dm_table_entry_t *, prop_array_t);
@@ -157,7 +157,7 @@ dm_target_snapshot_modcmd(modcmd_t cmd, void *arg)
dmt->version[1] = 0;
dmt->version[2] = 5;
dmt->init = &dm_target_snapshot_init;
- dmt->status = &dm_target_snapshot_status;
+ dmt->table = &dm_target_snapshot_table;
dmt->strategy = &dm_target_snapshot_strategy;
dmt->sync = &dm_target_snapshot_sync;
dmt->deps = &dm_target_snapshot_deps;
@@ -171,7 +171,7 @@ dm_target_snapshot_modcmd(modcmd_t cmd, void *arg)
dmt1->version[1] = 0;
dmt1->version[2] = 5;
dmt1->init = &dm_target_snapshot_orig_init;
- dmt1->status = &dm_target_snapshot_orig_status;
+ dmt1->table = &dm_target_snapshot_orig_table;
dmt1->strategy = &dm_target_snapshot_orig_strategy;
dmt1->sync = &dm_target_snapshot_orig_sync;
dmt1->deps = &dm_target_snapshot_orig_deps;
@@ -249,12 +249,12 @@ dm_target_snapshot_init(dm_table_entry_t *table_en, int argc, char **argv)
}
/*
* Status routine is called to get params string, which is target
* specific. When dm_table_status_ioctl is called with flag
* DM_STATUS_TABLE_FLAG I have to sent params string back.
*/
char *
-dm_target_snapshot_status(void *target_config)
+dm_target_snapshot_table(void *target_config)
{
dm_target_snapshot_config_t *tsc;
@@ -269,7 +269,7 @@ dm_target_snapshot_status(void *target_config)
cow_len = 0;
count = 0;
- printf("Snapshot target status function called\n");
+ printf("Snapshot target table function called\n");
/* count number of chars in offset */
for (i = tsc->tsc_chunk_size; i != 0; i /= 10)
@@ -415,12 +415,12 @@ dm_target_snapshot_orig_init(dm_table_entry_t *table_en, int argc, char **argv)
}
/*
* Status routine is called to get params string, which is target
* specific. When dm_table_status_ioctl is called with flag
* DM_STATUS_TABLE_FLAG I have to sent params string back.
*/
char *
-dm_target_snapshot_orig_status(void *target_config)
+dm_target_snapshot_orig_table(void *target_config)
{
dm_target_snapshot_origin_config_t *tsoc;
@@ -431,7 +431,7 @@ dm_target_snapshot_orig_status(void *target_config)
prm_len = 0;
- printf("Snapshot origin target status function called\n");
+ printf("Snapshot origin target table function called\n");
/* length of names + count of chars + spaces and null char */
prm_len = strlen(tsoc->tsoc_real_dev->name) + 1;
@@ -249,12 +249,12 @@ dm_target_snapshot_init(dm_table_entry_t *table_en, int argc, char **argv)
}
/*
- * Status routine is called to get params string, which is target
+ * Table routine is called to get params string, which is target
* specific. When dm_table_status_ioctl is called with flag
* DM_STATUS_TABLE_FLAG I have to sent params string back.
@@ -415,12 +415,12 @@ dm_target_snapshot_orig_init(dm_table_entry_t *table_en, int argc, char **argv)
}
/*
- * Status routine is called to get params string, which is target
+ * Table routine is called to get params string, which is target
* specific. When dm_table_status_ioctl is called with flag
* DM_STATUS_TABLE_FLAG I have to sent params string back.